@@ -15,6 +15,7 @@
 #include "informationsettings.h"
 #include "mousesettings.h"
 #include "mpvitem.h"
+#include "mpvpreview.h"
 #include "playbacksettings.h"
 #include "playlistitem.h"
 #include "playlistmodel.h"
@@ -26,6 +27,7 @@
 #include "videosettings.h"
 #include "worker.h"
 
+#include "mpvproperties.h"
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDesktopServices>
@@ -141,6 +143,7 @@ void Application::setupCommandLineParser()
 void Application::registerQmlTypes()
 {
     qmlRegisterType<MpvItem>("org.kde.haruna", 1, 0, "MpvItem");
+    qmlRegisterType<MpvPreview>("org.kde.haruna", 1, 0, "MpvPreview");
     qRegisterMetaType<PlayListModel *>();
     qRegisterMetaType<PlayListItem *>();
     qRegisterMetaType<TracksModel *>();
@@ -156,6 +159,7 @@ void Application::registerQmlTypes()
 
 void Application::setupQmlSettingsTypes()
 {
+    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "MpvProperties", MpvProperties::self());
     qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "AudioSettings", AudioSettings::self());
     qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "GeneralSettings", GeneralSettings::self());
     qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "InformationSettings", InformationSettings::self());
@@ -287,8 +291,10 @@ QString Application::formatTime(const double time)
     int minutes = (totalNumberOfSeconds / 60) % 60;
     int hours = (totalNumberOfSeconds / 60 / 60);
 
-    QString timeString =
-        QStringLiteral("%1:%2:%3").arg(hours, 2, 10, QLatin1Char('0')).arg(minutes, 2, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
+    QString hoursString = QStringLiteral("%1").arg(hours, 2, 10, QLatin1Char('0'));
+    QString minutesString = QStringLiteral("%1").arg(minutes, 2, 10, QLatin1Char('0'));
+    QString secondsString = QStringLiteral("%1").arg(seconds, 2, 10, QLatin1Char('0'));
+    QString timeString = QStringLiteral("%1:%2:%3").arg(hoursString, minutesString, secondsString);
 
     return timeString;
 }
@@ -318,6 +324,16 @@ QString Application::mimeType(QUrl url)
     return fileItem.mimetype();
 }
 
+void Application::handleSecondayInstanceMessage(const QByteArray &message)
+{
+    auto msgString = QString::fromStdString(message.data());
+    QFileInfo fileInfo{msgString};
+    if (fileInfo.exists() && fileInfo.isFile()) {
+        Q_EMIT openUrl(QUrl::fromUserInput(msgString));
+        raiseWindow();
+    }
+}
+
 QStringList Application::availableGuiStyles()
 {
     return QStyleFactory::keys();
