@@ -6,9 +6,11 @@
 
 #include "application.h"
 #include "generalsettings.h"
+#include "kdsingleapplication.h"
 #include "qqmlpropertymap.h"
 #include "thumbnailimageprovider.h"
 
+#include <QCommandLineParser>
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
@@ -41,6 +43,23 @@ int main(int argc, char *argv[])
 
     auto application = Application::instance();
 
+    KDSingleApplication kdsApp;
+    if (kdsApp.isPrimaryInstance()) {
+        QObject::connect(&kdsApp, &KDSingleApplication::messageReceived, [=](const QByteArray &message) {
+            application->handleSecondayInstanceMessage(message);
+        });
+    } else {
+        if (GeneralSettings::self()->useSingleInstance()) {
+            QCommandLineParser clParser;
+            clParser.process(qApplication);
+            if (clParser.positionalArguments().size() > 0) {
+                QString file = clParser.positionalArguments().first();
+                kdsApp.sendMessage(file.toUtf8());
+            }
+            exit(EXIT_SUCCESS);
+        }
+    }
+
     QQmlApplicationEngine engine(&qApplication);
     const QUrl url(QStringLiteral("qrc:/qml/main.qml"));
     auto onObjectCreated = [url](const QObject *obj, const QUrl &objUrl) {
