@@ -7,7 +7,9 @@
 #ifndef MPVCONTROLLER_H
 #define MPVCONTROLLER_H
 
+#include <QMap>
 #include <QObject>
+#include <QVariant>
 
 #include <mpv/client.h>
 #include <mpv/render_gl.h>
@@ -60,18 +62,21 @@ public:
     /**
      * Set the given property as mpv_node converted from the QVariant argument.
      *
+     * @param `property` the name of the property
      * @return mpv error code (<0 on error, >= 0 on success)
      */
-    Q_INVOKABLE int setProperty(const QString &name, const QVariant &value);
+    Q_INVOKABLE int setProperty(const QString &property, const QVariant &value);
+    Q_INVOKABLE int setPropertyAsync(const QString &property, const QVariant &value, int id = 0);
 
     /**
      * Return the given property as mpv_node converted to QVariant,
      * or QVariant() on error.
      *
-     * @param `name` the property name
+     * @param `property` the name of the property
      * @return the property value, or an ErrorReturn with the error code
      */
-    Q_INVOKABLE QVariant getProperty(const QString &name);
+    Q_INVOKABLE QVariant getProperty(const QString &property);
+    Q_INVOKABLE int getPropertyAsync(const QString &property, int id = 0);
 
     /**
      * mpv_command_node() equivalent.
@@ -80,6 +85,7 @@ public:
      * @return the property value, or an ErrorReturn with the error code
      */
     Q_INVOKABLE QVariant command(const QVariant &params);
+    Q_INVOKABLE int commandAsync(const QVariant &params, int id = 0);
 
     /**
      * Return an error string from an ErrorReturn.
@@ -92,6 +98,7 @@ public:
 
 Q_SIGNALS:
     void propertyChanged(const QString &property, const QVariant &value);
+    void asyncReply(const QVariant &value = QVariant(), int id = 0);
     void fileStarted();
     void fileLoaded();
     void endFile(QString reason);
