@@ -115,10 +115,6 @@ void MpvItem::initProperties()
     //    setProperty(QStringLiteral("terminal"), InformationSettings::mpvLogging());
     //    setProperty(QStringLiteral("msg-level"), QStringLiteral("all=v"));
 
-    // lockManager is connected to the pauseChanged signal
-    // by setting `pause` to true it ensures the signal is triggered at startup
-    setProperty(MpvProperties::self()->Pause, true);
-
     QString hwdec = PlaybackSettings::useHWDecoding() ? PlaybackSettings::hWDecoding() : QStringLiteral("no");
     setProperty(MpvProperties::self()->HardwareDecoding, hwdec);
     setProperty(MpvProperties::self()->VolumeMax, QStringLiteral("100"));
@@ -151,11 +147,11 @@ void MpvItem::initProperties()
     setProperty(MpvProperties::self()->AudioClientName, QStringLiteral("haruna"));
     const QVariant preferredAudioTrack = AudioSettings::preferredTrack();
     setProperty(MpvProperties::self()->AudioId, preferredAudioTrack == 0 ? QStringLiteral("auto") : preferredAudioTrack);
-    setProperty(MpvProperties::self()->AudioLanguage, AudioSettings::preferredLanguage());
+    setProperty(MpvProperties::self()->AudioLanguage, AudioSettings::preferredLanguage().remove(QStringLiteral(" ")));
 
     const QVariant preferredSubTrack = SubtitlesSettings::preferredTrack();
     setProperty(MpvProperties::self()->SubtitleId, preferredSubTrack == 0 ? QStringLiteral("auto") : preferredSubTrack);
-    setProperty(MpvProperties::self()->SubtitleLanguage, SubtitlesSettings::preferredLanguage());
+    setProperty(MpvProperties::self()->SubtitleLanguage, SubtitlesSettings::preferredLanguage().remove(QStringLiteral(" ")));
     setProperty(MpvProperties::self()->SubtitleFilePaths, SubtitlesSettings::subtitlesFolders().join(QStringLiteral(":")));
 }
 
